@@ -1,7 +1,7 @@
 #!/usr/bin/env ruby
 
 #---
-# Copyright 2003-2011 by Jim Weirich (jim@weirichhouse.org).
+# Copyright 2003-2013 by Jim Weirich (jim.weirich@gmail.com).
 # All rights reserved.
 
 # Permission is granted for use, copying, modification, distribution,
@@ -9,6 +9,10 @@
 # above copyright notice is included.
 #+++
 
+require 'flexmock/symbol_extensions'
+require 'flexmock/object_extensions'
+require 'flexmock/class_extensions'
+
 require 'flexmock/core'
 
 require 'flexmock/default_framework_adapter'
@@ -22,3 +26,4 @@ require 'flexmock/mock_container'
 require 'flexmock/partial_mock'
 require 'flexmock/undefined'
 require 'flexmock/deprecated_methods'
+require 'flexmock/extensions/active_record_model'
