@@ -1,7 +1,7 @@
 #!/usr/bin/env ruby
 
 #---
-# Copyright 2003-2011 by Jim Weirich (jim@weirichhouse.org).
+# Copyright 2003-2013 by Jim Weirich (jim.weirich@gmail.com).
 # All rights reserved.
 
 # Permission is granted for use, copying, modification, distribution,
@@ -13,14 +13,15 @@ require 'flexmock/noop'
 
 class FlexMock
   class DefaultFrameworkAdapter
-    def assert_block(msg, &block)
+    def make_assertion(msg, &block)
       unless yield
+        msg = msg.call if msg.is_a?(Proc)
         fail assertion_failed_error, msg
       end
     end
 
-    def assert_equal(a, b, msg=nil)
-      assert_block(msg || "Expected equal") { a == b }
+    def check(msg, &block)
+      make_assertion(msg, &block)
     end
 
     class AssertionFailedError < StandardError; end
