@@ -1,7 +1,7 @@
 #!/usr/bin/env ruby
 
 #---
-# Copyright 2003-2011 by Jim Weirich (jim.weirich@gmail.com).
+# Copyright 2003-2013 by Jim Weirich (jim.weirich@gmail.com).
 # All rights reserved.
 
 # Permission is granted for use, copying, modification, distribution,
@@ -9,6 +9,8 @@
 # above copyright notice is included.
 #+++
 
+
+
 require 'flexmock/base'
 
 class FlexMock
@@ -19,20 +21,26 @@ class FlexMock
   end
 
   class RSpecFrameworkAdapter
-    def assert_block(msg, &block)
+    def make_assertion(msg, backtrace = caller, &block)
+      msg = msg.call if msg.is_a?(Proc)
       SpecModule::Expectations.fail_with(msg) unless yield
     end
 
-    def assert_equal(a, b, msg=nil)
-      message = msg || "Expected equal"
-      assert_block(message + "\n<#{a}> expected, but was\n<#{b}>") { a == b }
+    def check(msg, &block)
+      make_assertion(msg, &block)
     end
 
     class AssertionFailedError < StandardError; end
+
     def assertion_failed_error
       SpecModule::Expectations::ExpectationNotMetError
     end
+    def check_failed_error
+      assertion_failed_error
+    end
   end
 
   @framework_adapter = RSpecFrameworkAdapter.new
 end
+
+require 'flexmock/rspec_spy_matcher'
