@@ -452,6 +452,31 @@ class TestFlexMockShoulds < Minitest::Test
     end
   end
 
+  def test_with_kw_args_matches_values_separately
+    FlexMock.use('greeter') do |m|
+      m.should_receive(:hi).with_kw_args(a: on { |v| v == 1 }, b: 2).once
+      m.hi(a: 1, b: 2)
+    end
+  end
+
+  def test_with_kw_args_raises_if_an_expected_key_is_missing
+    assert_raises(FlexMock::CheckFailedError) do
+      FlexMock.use('greeter') do |m|
+        m.should_receive(:hi).with_kw_args(a: on { |v| v == 1 }, b: 2).once
+        m.hi(a: 1)
+      end
+    end
+  end
+
+  def test_with_kw_args_raises_if_there_is_an_actual_key_too_much
+    assert_raises(FlexMock::CheckFailedError) do
+      FlexMock.use('greeter') do |m|
+        m.should_receive(:hi).with_kw_args(a: on { |v| v == 1 }, b: 2).once
+        m.hi(a: 1, b: 2, c: 3)
+      end
+    end
+  end
+
   def test_with_kw_not_matching
     FlexMock.use('greeter') do |m|
       m.should_receive(:hi).with(1, a: 2)
@@ -1422,7 +1447,7 @@ class TestFlexMockShoulds < Minitest::Test
     k = Class.new { def m(req_a, req_b, opt_c = 10); end }
     FlexMock.use do |mock|
       e = mock.should_receive(:m).with_signature_matching(k.instance_method(:m))
-      e = e.instance_variable_get(:@expectations).first
+      e = e.expectations.first
       validator = e.instance_variable_get(:@signature_validator)
       assert_equal 2, validator.required_arguments
       assert_equal 1, validator.optional_arguments
@@ -1437,7 +1462,7 @@ class TestFlexMockShoulds < Minitest::Test
     k = Class.new { def m(req_a, req_b, opt_c = 10, *splat); end }
     FlexMock.use do |mock|
       e = mock.should_receive(:m).with_signature_matching(k.instance_method(:m))
-      e = e.instance_variable_get(:@expectations).first
+      e = e.expectations.first
       validator = e.instance_variable_get(:@signature_validator)
       assert_equal 2, validator.required_arguments
       assert_equal 1, validator.optional_arguments
